@@ -31,7 +31,7 @@ class FlowState:
 
 async def compute_flow(graph):
 
-    logger.debug("enter")
+    logger.debug("enter, graph.name=%s", graph.name)
 
     if not hasattr(graph, "__flow_state"):
         logger.debug("First invocation, initialising flow state")
@@ -85,6 +85,7 @@ async def compute_flow(graph):
         return len(flow_state.input_tasks)
     except asyncio.CancelledError:
         await aio.cancel_tasks(flow_state.input_tasks)
+        logger.debug("Caught asyncio.CancelledError")
         # Don't reraise - this is an expected error when cancelling the
         # flow with `cancel_flow`
     except Exception:
@@ -92,11 +93,12 @@ async def compute_flow(graph):
         # Reraise - this is an unexpected exception
         raise
     finally:
-        logger.debug("exit, len(flow_state.input_tasks)=%s",
-                     len(flow_state.input_tasks))
+        logger.debug("exit, graph.name=%s, len(flow_state.input_tasks)=%s",
+                     graph.name, len(flow_state.input_tasks))
 
 
 async def cancel_flow(graph):
     if not hasattr(graph, "__flow_state"):
         raise Exception("Graph does not have __flow_state attribute")
+    logger.debug("cancelling task in %s", graph.name)
     await aio.cancel_tasks(graph.__flow_state.input_tasks)
